@@ -1,15 +1,20 @@
-import requests, sys, json
+import requests, sys, json, base64
 
 base_parameters={
     "api-version":"7.1-preview.1"
 }
 
-def create_pr(api_url, TOKEN, REPO_ID, params, sourceRefName, targetRefName, pr_title) -> object:
+def create_headers(TOKEN=str) -> str:
+    credenciales = f"{TOKEN}"
+    credenciales_base64 = base64.b64encode(credenciales.encode('utf-8')).decode('utf-8')
+    return credenciales_base64
+
+def create_pr(API_URL=str, TOKEN=str, REPO_ID=str, sourceRefName=str, targetRefName=str, pr_title=str, headers=object|None, data=object|None, params=object|None) -> object:
     """
     Creates a Pull Request (PR) in a specified repository.
 
     Args:
-        api_url (str): Base URL of the API for creating PRs.
+        API_URL (str): Base URL of the API for creating PRs.
         TOKEN (str): Authorization token for API access.
         REPO_ID (str): The ID of the repository where the PR will be created.
         params (dict): Additional parameters for creating the PR.
@@ -19,25 +24,45 @@ def create_pr(api_url, TOKEN, REPO_ID, params, sourceRefName, targetRefName, pr_
 
     Returns:
         object: Dictionary with information about the success or failure of the PR creation, including function code and PR details.
+        Formato del diccionario de respuesta:
+        
+        - En caso de éxito:
+            {
+                "function_code": <valor>,
+                "message": <mensaje_de_éxito>,
+                "lastMergeSourceCommit": <último_commit_de_la_fusión>,
+                "pullRequestId": <ID_del_PR>
+            }
+
+        - En caso de fallo:
+            {
+                "function_code": <valor>,
+                "message": <mensaje_de_error>
+            }
     """
 
-    body_pr=json.dumps({
+    body_pr={
         "sourceRefName": f"refs/heads/{sourceRefName}",
         "targetRefName": f"refs/heads/{targetRefName}",
         "title": f"{pr_title} {sourceRefName} to {targetRefName}"
-    })
-    headers = {
+    }
+    base_headers = {
         'Content-Type': 'application/json',
         'Accept': 'application/json',
         "Authorization": f"Basic {TOKEN}"
     }
-    if params:
-        base_parameters.update(params) 
+    if params is not None and isinstance(params, dict):
+        base_parameters.update(params)
+    if headers is not None and isinstance(headers, dict):
+        base_headers.update(headers)
+    if data is not None and isinstance(data, dict):
+        body_pr.update(data)
     try:
-        response=json.loads(requests.post(url=f"{api_url}/repositories/{REPO_ID}/pullrequests", data=body_pr, headers=headers, params=base_parameters).text)
+        response=json.loads(requests.post(url=f"{API_URL}/repositories/{REPO_ID}/pullrequests", data=json.dumps(body_pr), headers=base_headers, params=base_parameters).text)
         if response['status_code'] == 201 and response['status'] == "active":
             def_response={
                 "function_code":200,
+                "message": "PR Creada correctamente",
                 "lastMergeSourceCommit": {f"{response['lastMergeSourceCommit']}"},
                 "pullRequestId": f"{response['pullRequestId']}"
             }
@@ -51,12 +76,12 @@ def create_pr(api_url, TOKEN, REPO_ID, params, sourceRefName, targetRefName, pr_
         print(f"Error al crear la pr \n {e.strerror}")
         sys.exit(1)
 
-def get_pr_data(api_url, TOKEN, REPO_ID, params, sourceBranch, targetBranch) -> object:
+def get_pr_data(API_URL=str, TOKEN=str, REPO_ID=str, sourceRefName=str, targetRefName=str, headers=object|None, params=object|None) -> object:
     """
     Retrieves data about a specific Pull Request (PR) based on branch information.
 
     Args:
-        api_url (str): Base URL of the API for retrieving PR data.
+        API_URL (str): Base URL of the API for retrieving PR data.
         TOKEN (str): Authorization token for API access.
         REPO_ID (str): The ID of the repository to search for the PR.
         params (dict): Additional parameters for retrieving PR data.
@@ -65,24 +90,39 @@ def get_pr_data(api_url, TOKEN, REPO_ID, params, sourceBranch, targetBranch) ->
 
     Returns:
         object: Dictionary with information about the PR, including function code and response data.
+        Formato del diccionario de respuesta:
+        
+        - En caso de éxito:
+            {
+                "function_code": <valor>,
+                "message": <mensaje_de_éxito>
+            }
+
+        - En caso de fallo:
+            {
+                "function_code": <valor>,
+                "message": <mensaje_de_error>
+            }
     """
 
     parameters_get_prs={
     "searchCriteria.repositoryId":f"{REPO_ID}",
     "searchCriteria.status":"active",
-    "searchCriteria.targetRefName":f"{targetBranch}",
-    "searchCriteria.sourceRefName":f"{sourceBranch}"
+    "searchCriteria.targetRefName":f"{targetRefName}",
+    "searchCriteria.sourceRefName":f"{sourceRefName}"
     }
-    headers={
+    base_headers={
         "Content-Type": "application/json",
         "Accept": "application/json",
         "Authorization": f"Basic {TOKEN}"
     }
     base_parameters.update(parameters_get_prs)
-    if params:
+    if params is not None and isinstance(params, dict):
         base_parameters.update(params)
+    if headers is not None and isinstance(headers, dict):
+        base_headers.update(headers)
     try:
-        response=json.loads(requests.get(url=f"{api_url}/pullrequests", params=base_parameters, headers=headers).text)
+        response=json.loads(requests.get(url=f"{API_URL}/pullrequests", params=base_parameters, headers=base_parameters).text)
         if response['status_code'] == 200:
             def_response={
                     "function_code":200,
@@ -98,12 +138,12 @@ def get_pr_data(api_url, TOKEN, REPO_ID, params, sourceBranch, targetBranch) ->
         print(f"Error al obtener datos de la PR: \n {e.strerror}")
         sys.exit(1)
 
-def add_reviwer(api_url, TOKEN, REPO_ID, params, pullRequestId, reviewerId) -> object:
+def add_reviwer(API_URL=str, TOKEN=str, REPO_ID=str, pullRequestId=str, reviewerId=str, headers=object|None, data=object|None, params=object|None) -> object:
     """
     Adds a required reviewer to a Pull Request.
 
     Args:
-        api_url (str): Base URL of the API for adding a reviewer.
+        API_URL (str): Base URL of the API for adding a reviewer.
         TOKEN (str): Authorization token for API access.
         REPO_ID (str): The ID of the repository where the PR is located.
         params (dict): Additional parameters for adding the reviewer.
@@ -112,21 +152,38 @@ def add_reviwer(api_url, TOKEN, REPO_ID, params, pullRequestId, reviewerId) -> o
 
     Returns:
         object: Dictionary with information about the success or failure of the operation, including function code and a message.
+        Formato del diccionario de respuesta:
+        
+        - En caso de éxito:
+            {
+                "function_code": <valor>,
+                "message": <mensaje_de_éxito>
+            }
+
+        - En caso de fallo:
+            {
+                "function_code": <valor>,
+                "message": <mensaje_de_error>
+            }
     """
 
-    data = {
+    body = {
         "vote": 0,
         "isRequired": True
     }
-    headers={
+    base_headers={
         "Content-Type": "application/json",
         "Accept": "application/json",
         "Authorization": f"Basic {TOKEN}"
     }
-    if params:
+    if params is not None and isinstance(params, dict):
         base_parameters.update(params)
+    if headers is not None and isinstance(headers, dict):
+        base_headers.update(headers)
+    if data is not None and isinstance(data, dict):
+        body.update(data)
     try:
-        response = requests.put(url=f"{api_url}/repositories/{REPO_ID}/pullrequests/{pullRequestId}/reviewers/{reviewerId}", headers=headers, params=base_parameters, data=json.dumps(data))
+        response = requests.put(url=f"{API_URL}/repositories/{REPO_ID}/pullrequests/{pullRequestId}/reviewers/{reviewerId}", headers=base_headers, params=base_parameters, data=json.dumps(body))
         if response.status_code == 200:
             json_response={
                 "funcition_code":200,
@@ -142,12 +199,12 @@ def add_reviwer(api_url, TOKEN, REPO_ID, params, pullRequestId, reviewerId) -> o
         print(f"Error al añadir un reviwer: \n {e.strerror}")
         sys.exit(1)
 
-def approve_pr(api_url, TOKEN, REPO_ID, params, pullRequestId, reviewerId) -> object:
+def approve_pr(API_URL=str, TOKEN=str, REPO_ID=str, pullRequestId=str, reviewerId=str, headers=object|None, data=object|None, params=object|None) -> object:
     """
     Approves a Pull Request as a reviewer.
 
     Args:
-        api_url (str): Base URL of the API for approving a PR.
+        API_URL (str): Base URL of the API for approving a PR.
         TOKEN (str): Authorization token for API access.
         REPO_ID (str): The ID of the repository where the PR is located.
         params (dict): Additional parameters for approving the PR.
@@ -156,16 +213,35 @@ def approve_pr(api_url, TOKEN, REPO_ID, params, pullRequestId, reviewerId) -> ob
 
     Returns:
         object: Dictionary with information about the success or failure of the operation, including function code and a message.
+        Formato del diccionario de respuesta:
+        
+        - En caso de éxito:
+            {
+                "function_code": <valor>,
+                "message": <mensaje_de_éxito>
+            }
+
+        - En caso de fallo:
+            {
+                "function_code": <valor>,
+                "message": <mensaje_de_error>
+            }
     """
 
-    data = {
+    body = {
         "vote": 10  # 10 significa que el revisor aprueba la PR
     }
-    headers={
+    base_headers={
         "Authorization": f"Basic {TOKEN}"
     }
+    if params is not None and isinstance(params, dict):
+        base_parameters.update(params)
+    if headers is not None and isinstance(headers, dict):
+        base_headers.update(headers)
+    if data is not None and isinstance(data, dict):
+        body.update(data)
     try:
-        response = requests.put(url=f"{api_url}/repositories/{REPO_ID}/pullrequests/{pullRequestId}/reviewers/{reviewerId}", headers=headers, data=json.dumps(data))
+        response = requests.put(url=f"{API_URL}/repositories/{REPO_ID}/pullrequests/{pullRequestId}/reviewers/{reviewerId}", headers=base_headers, data=json.dumps(body), params=base_parameters)
         if response.status_code == 200:
             json_response={
                 "funcition_code":200,
@@ -181,12 +257,12 @@ def approve_pr(api_url, TOKEN, REPO_ID, params, pullRequestId, reviewerId) -> ob
         print(f"Error al aprobar la pr: \n {e.strerror}")
         sys.exit(1)
 
-def complete_pr(api_url, TOKEN, REPO_ID, params, pullRequestId, commitData) -> object:
+def complete_pr(API_URL=str, TOKEN=str, REPO_ID=str, pullRequestId=str, commitData=str, headers=object|None, data=object|None, params=object|None) -> object:
     """
     Completes (merges) a Pull Request.
 
     Args:
-        api_url (str): Base URL of the API for completing a PR.
+        API_URL (str): Base URL of the API for completing a PR.
         TOKEN (str): Authorization token for API access.
         REPO_ID (str): The ID of the repository where the PR is located.
         params (dict): Additional parameters for completing the PR.
@@ -195,27 +271,46 @@ def complete_pr(api_url, TOKEN, REPO_ID, params, pullRequestId, commitData) -> o
 
     Returns:
         object: Dictionary with information about the success or failure of the operation, including function code and a message.
+        Formato del diccionario de respuesta:
+        
+        - En caso de éxito:
+            {
+                "function_code": <valor>,
+                "message": <mensaje_de_éxito>
+            }
+
+        - En caso de fallo:
+            {
+                "function_code": <valor>,
+                "message": <mensaje_de_error>
+            }
     """
 
-    data = {
+    body = {
         "status": "completed",
         "lastMergeSourceCommit": {
             "commitId": f"{commitData['commitId']}",
             "url": f"{commitData['url']}"
         },
         "completionOptions": {
-            "deleteSourceBranch": True,
+            "deleteSourceBranch": False,
             "mergeCommitMessage": "PR completada automáticamente",
             "squashMerge": False
         }
     }
-    headers={
+    base_headers={
         "Content-Type": "application/json",
         "Accept": "application/json",
         "Authorization": f"Basic {TOKEN}"
     }
+    if params is not None and isinstance(params, dict):
+        base_parameters.update(params)
+    if headers is not None and isinstance(headers, dict):
+        base_headers.update(headers)
+    if data is not None and isinstance(data, dict):
+        body.update(data)
     try:
-        response = requests.post(url=f"{api_url}/repositories/{REPO_ID}/pullrequests/{pullRequestId}", headers=headers, data=json.dumps(data), params=params)
+        response = requests.post(url=f"{API_URL}/repositories/{REPO_ID}/pullrequests/{pullRequestId}", headers=base_headers, data=json.dumps(body), params=base_parameters)
         if response.status_code == 200:
             json_response={
                 "funcition_code":200,
@@ -231,25 +326,44 @@ def complete_pr(api_url, TOKEN, REPO_ID, params, pullRequestId, commitData) -> o
         print(f"Error al completar la pr: \n {e.strerror}")
         sys.exit(1)
 
-def get_project(api_url, TOKEN, name) -> object:
+def get_project(API_URL=str, TOKEN=str, name=str, headers=object|None, params=object|None) -> object:
     """
     Retrieves information about a project by its name.
 
     Args:
-        api_url (str): Base URL of the API for retrieving project information.
+        API_URL (str): Base URL of the API for retrieving project information.
         TOKEN (str): Authorization token for API access.
         name (str): Name of the project to retrieve.
 
     Returns:
         object: Dictionary with information about the success or failure of the operation, including function code and project ID.
+        Formato del diccionario de respuesta:
+        
+        - En caso de éxito:
+            {
+                "function_code": <valor>,
+                "message": <mensaje_de_éxito>,
+                "projectId": <Id del proyecto>
+            }
+
+        - En caso de fallo:
+            {
+                "function_code": <valor>,
+                "message": <mensaje_de_éxito>,
+                "projectId": <Id del proyecto>
+            }
     """
 
-    headers = {
+    base_headers = {
         'Accept': 'application/json',
         'Authorization': f'Basic {TOKEN}'
     }
+    if params is not None and isinstance(params, dict):
+        base_parameters.update(params)
+    if headers is not None and isinstance(headers, dict):
+        base_headers.update(headers)
     try:
-        response = requests.get(url=f"{api_url}/_apis/projects", headers=headers, params=base_parameters)
+        response = requests.get(url=f"{API_URL}/_apis/projects", headers=base_headers, params=base_parameters)
         if response.status_code == 200:
             for project in response['value']:
                 if project['name'] == name:
@@ -261,6 +375,7 @@ def get_project(api_url, TOKEN, name) -> object:
         else:
             json_response={
                 "funcition_code":f"{response.status_code}",
+                "projectId": "0",
                 "message":f"{response.text}"
             }
         return json_response
@@ -268,37 +383,57 @@ def get_project(api_url, TOKEN, name) -> object:
         print(f"Error al obtener los proyectos: \n {e.strerror}")
         sys.exit(1)
 
-def get_teams_by_projectId(api_url, TOKEN, project_id, team_name) -> object:
+def get_teams_by_projectId(API_URL=str, TOKEN=str, REPO_ID=str, project_id=str, team_name=str, headers=object|None, params=object|None) -> object:
     """
     Retrieves information about a specific team in a project by its name.
 
     Args:
-        api_url (str): Base URL of the API for retrieving team information.
+        API_URL (str): Base URL of the API for retrieving team information.
         TOKEN (str): Authorization token for API access.
         project_id (str): ID of the project.
         team_name (str): Name of the team to retrieve.
 
     Returns:
         object: Dictionary with information about the success or failure of the operation, including function code and team ID.
+        Formato del diccionario de respuesta:
+        
+        - En caso de éxito:
+            {
+                "function_code": <valor>,
+                "message": <mensaje_de_éxito>,
+                "teamId": <Id del team>
+            }
+
+        - En caso de fallo:
+            {
+                "function_code": <valor>,
+                "message": <mensaje_de_éxito>,
+                "teamId": <Id del team>
+            }
     """
 
-    headers = {
+    base_headers = {
         'Accept': 'application/json',
         'Authorization': f'Basic {TOKEN}'
     }
+    if params is not None and isinstance(params, dict):
+        base_parameters.update(params)
+    if headers is not None and isinstance(headers, dict):
+        base_headers.update(headers)
     try:
-        response = requests.get(url=f"{api_url}/_apis/projects/{project_id}/teams", headers=headers, params=base_parameters)
+        response = requests.get(url=f"{API_URL}/_apis/projects/{project_id}/teams", headers=base_headers, params=base_parameters)
         if response.status_code == 200:
             for team in response['value']:
                 if team['name'] == team_name:
                     json_response={
                         "funcition_code":200,
-                        "projectId": f"{team['id']}",
+                        "teamId": f"{team['id']}",
                         "message":f"Obtencion de equipos correcto"
                     }
         else:
             json_response={
                 "funcition_code":f"{response.status_code}",
+                "teamId": "0",
                 "message":f"{response.text}"
             }
         return json_response
@@ -306,12 +441,12 @@ def get_teams_by_projectId(api_url, TOKEN, project_id, team_name) -> object:
         print(f"Error al obtener los equipos: \n {e.strerror}")
         sys.exit(1)
 
-def get_reviewer_id_by_team_id(api_url, TOKEN, project_id, team_id, user_email) -> object:
+def get_reviewer_id_by_team_id(API_URL=str, TOKEN=str, REPO_ID=str, project_id=str, team_id=str, user_email=str, headers=object|None, params=object|None) -> object:
     """
     Retrieves the reviewer ID by team ID and user email.
 
     Args:
-        api_url (str): Base URL of the API for retrieving reviewer information.
+        API_URL (str): Base URL of the API for retrieving reviewer information.
         TOKEN (str): Authorization token for API access.
         project_id (str): ID of the project.
         team_id (str): ID of the team.
@@ -319,28 +454,106 @@ def get_reviewer_id_by_team_id(api_url, TOKEN, project_id, team_id, user_email)
 
     Returns:
         object: Dictionary with information about the success or failure of the operation, including function code and reviewer ID.
+        Formato del diccionario de respuesta:
+        
+        - En caso de éxito:
+            {
+                "function_code": <valor>,
+                "message": <mensaje_de_éxito>,
+                "reviwerId": <Id del reviwer>
+            }
+
+        - En caso de fallo:
+            {
+                "function_code": <valor>,
+                "message": <mensaje_de_éxito>,
+                "reviwerId": <Id del reviwer>
+            }
     """
 
-    headers = {
+    base_headers = {
         'Accept': 'application/json',
         'Authorization': f'Basic {TOKEN}'
     }
+    if params is not None and isinstance(params, dict):
+        base_parameters.update(params)
+    if headers is not None and isinstance(headers, dict):
+        base_headers.update(headers)
     try:
-        response = requests.get(url=f"{api_url}/_apis/projects/{project_id}/teams/{team_id}/members", headers=headers, params=base_parameters)
+        response = requests.get(url=f"{API_URL}/_apis/projects/{project_id}/teams/{team_id}/members", headers=base_headers, params=base_parameters)
         if response.status_code == 200:
             for user in response:
                 if user['uniqueName'] == user_email:
                     json_response={
                         "funcition_code":200,
-                        "projectId": f"{user['id']}",
+                        "reviwerId": f"{user['id']}",
                         "message":f"Obtencion de Id de usuario correcto"
                     }
         else:
             json_response={
                 "funcition_code":f"{response.status_code}",
+                "reviwerId": "0",
                 "message":f"{response.text}"
             }
         return json_response
     except requests.RequestException as e:
         print(f"Error al obtener los miembros del equipo: \n {e.strerror}")
         sys.exit(1)
+
+def get_repo_id(API_URL=str, TOKEN=str, repo_name=str, headers=object|None, params=object|None) -> object:
+    """
+    Retrieves the reviewer ID by team ID and user email.
+
+    Args:
+        API_URL (str): Base URL of the API for retrieving reviewer information.
+        TOKEN (str): Authorization token for API access.
+        repo_name (str): Repo name to obtain.
+
+    Returns:
+        object: Dictionary with information about the success or failure of the operation, including function code and repo ID.
+        Formato del diccionario de respuesta:
+        
+        - En caso de éxito:
+            {
+                "function_code": <valor>,
+                "message": <mensaje_de_éxito>,
+                "repoId": <Id del reviwer>
+            }
+
+        - En caso de fallo:
+            {
+                "function_code": <valor>,
+                "message": <mensaje_de_éxito>,
+                "repoId": <Id del reviwer>
+            }
+    """
+
+    base_headers = {
+        'Accept': 'application/json',
+        'Authorization': f'Basic {TOKEN}'
+    }
+    if params is not None and isinstance(params, dict):
+        base_parameters.update(params)
+    if headers is not None and isinstance(headers, dict):
+        base_headers.update(headers)
+    try:
+        response = requests.get(url=f"{API_URL}/_apis/repositories", headers=base_headers, params=base_parameters)
+        if response.status_code == 200:
+            for repos in response:
+                if repos['uniqueName'] == repo_name:
+                    json_response={
+                        "funcition_code":200,
+                        "repoId": f"{repos['id']}",
+                        "message":f"Obtencion de Id de usuario correcto"
+                    }
+        else:
+            json_response={
+                "funcition_code":f"{response.status_code}",
+                "repoId": "0",
+                "message":f"{response.text}"
+            }
+        return json_response
+    except requests.RequestException as e:
+        print(f"Error al obtener los miembros del equipo: \n {e.strerror}")
+        sys.exit(1)
+
